@@ -1,19 +1,24 @@
-(*
- * Calendar library
- * Copyright (C) 2003 Julien SIGNOLES
- * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2, as published by the Free Software Foundation.
- * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * See the GNU Library General Public License version 2 for more details
- *)
+(**************************************************************************)
+(*                                                                        *)
+(*  This file is part of Calendar.                                        *)
+(*                                                                        *)
+(*  Copyright (C) 2003-2008 Julien Signoles                               *)
+(*                                                                        *)
+(*  you can redistribute it and/or modify it under the terms of the GNU   *)
+(*  Lesser General Public License version 2.1 as published by the         *)
+(*  Free Software Foundation.                                             *)
+(*                                                                        *)
+(*  It is distributed in the hope that it will be useful,                 *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
+(*  GNU Lesser General Public License for more details.                   *)
+(*                                                                        *)
+(*  See the GNU Lesser General Public Licence version 2.1 for more        *)
+(*  details (enclosed in the file LGPL).                                  *)
+(*                                                                        *)
+(**************************************************************************)
 
-(*i $Id: date.ml,v 1.28 2006/07/07 13:48:10 signoles Exp $ i*)
+(*i $Id: date.ml,v 1.34 2008/02/08 13:06:45 signoles Exp $ i*)
 
 (*S Introduction.
 
@@ -24,7 +29,7 @@
 
 (*S Datatypes. *)
 
-type t = int (*r Representing the Julian day *)
+include Utils.Int (* the integer represents the Julian day *)
 
 type day = Sun | Mon | Tue | Wed | Thu | Fri | Sat
 
@@ -56,7 +61,8 @@ external int_of_month : month -> int = "%identity"
 
 (*S Constructors. *)
 
-let lt (d1 : int * int * int) (d2 : int * int * int) = compare d1 d2 < 0
+let lt (d1 : int * int * int) (d2 : int * int * int) = 
+  Pervasives.compare d1 d2 < 0
 
 (* [date_ok] returns [true] is the date belongs to the Julian period;
    [false] otherwise. *)
@@ -96,14 +102,14 @@ let from_unixfloat x =
   let d = int_of_float (x /. 86400.) + jan_1_1970 in
   current_day d (Unix.gmtime x).Unix.tm_hour
 
+let from_day_of_year y d = make y 1 d
+
 let today () = from_unixfloat (Unix.time ())
 
 let from_jd n = n
-
 let to_jd d = d
 
 let from_mjd x = x + 2400001
-
 let to_mjd d = d - 2400001
 
 (*S Useful operations. *)
@@ -120,12 +126,7 @@ let is_leap_year y =
 
 (*S Boolean operations on dates. *)
 
-let compare = compare
-
-let equal = (==)
-
 let is_julian d = d < 2299161
-
 let is_gregorian d = d >= 2299161
 
 (*S Getters. *)
@@ -182,6 +183,13 @@ let days_in_month d =
 let is_leap_day d = 
   is_leap_year (year d) && month d = Feb && day_of_month d = 24
 
+let is_valid_date y m d =
+  try
+    let t = make y m d in
+    year t = y && int_month t = m && day_of_month t = d
+  with Out_of_bounds | Undefined -> 
+    false
+
 (*S Period. *)
 
 module Period = struct
@@ -198,28 +206,22 @@ module Period = struct
   let empty = { y = 0; m = 0; d = 0 }
 
   let make y m d = { y = y; m = m; d = d }
-
   let lmake ?(year = 0) ?(month = 0) ?(day = 0) () = make year month day
 
   let day n = { empty with d = n }
-
   let week n = { empty with d = 7 * n }
-
   let month n = { empty with m = n }
-
   let year n = { empty with y = n }
 
   let add x y = { y = x.y + y.y; m = x.m + y.m; d = x.d + y.d }
-
   let sub x y = { y = x.y - y.y; m = x.m - y.m; d = x.d - y.d }
-
   let opp x = { y = - x.y; m = - x.m; d = - x.d }
 
   (* Lexicographical order over the fields of the type [t].
      Yep, [Pervasives.compare] correctly works. *)
   let compare = Pervasives.compare
-
-  let equal = (=)
+  let equal = Pervasives.(=)
+  let hash = Hashtbl.hash
 
   exception Not_computable
 
@@ -286,8 +288,6 @@ let week_first_last w y =
   b, 6 + b
 
 let nth_weekday_of_month y m d n =
-(*  let first = make y (int_of_month m + 1) 1 in
-  first + int_of_day d - int_day_of_week first + (n - 1) * 7*)
   let first = make y (int_of_month m + 1) 1 in
   let gap =
     let diff = int_of_day d - int_day_of_week first in
@@ -377,8 +377,11 @@ let int_of_day d = let n = int_of_day d in if n = 0 then 7 else n
   (* Used by [from_business] *)
 
 let from_business y w d =
-  if w < 1 || w > weeks_in_year y then invalid_arg "from_business";
-  let first = make y 1 1 in
+  if w < 1 || w > weeks_in_year y then invalid_arg "from_business: bad week";
+  let first = 
+    try make y 1 1 
+    with Out_of_bounds | Undefined -> invalid_arg "from_business: bad date"
+  in
   let first_day = int_day_of_week first in
   let w = if first_day > 4 then w else w - 1 in
   first + w * 7 + int_of_day d - first_day
