@@ -1,19 +1,24 @@
-(*
- * Calendar library
- * Copyright (C) 2003 Julien SIGNOLES
- * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2, as published by the Free Software Foundation.
- * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * See the GNU Library General Public License version 2 for more details
- *)
+(**************************************************************************)
+(*                                                                        *)
+(*  This file is part of Calendar.                                        *)
+(*                                                                        *)
+(*  Copyright (C) 2003-2008 Julien Signoles                               *)
+(*                                                                        *)
+(*  you can redistribute it and/or modify it under the terms of the GNU   *)
+(*  Lesser General Public License version 2.1 as published by the         *)
+(*  Free Software Foundation.                                             *)
+(*                                                                        *)
+(*  It is distributed in the hope that it will be useful,                 *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
+(*  GNU Lesser General Public License for more details.                   *)
+(*                                                                        *)
+(*  See the GNU Lesser General Public Licence version 2.1 for more        *)
+(*  details (enclosed in the file LGPL).                                  *)
+(*                                                                        *)
+(**************************************************************************)
 
-(*i $Id: printer.ml,v 1.12 2007/05/14 09:20:39 signoles Exp $ i*)
+(*i $Id: printer.ml,v 1.17 2008/02/15 07:38:25 signoles Exp $ i*)
 
 module type S = sig
   type t
@@ -48,7 +53,7 @@ let month_name =
   ref (function
 	 | Date.Jan -> "January"
 	 | Date.Feb -> "February"
-	 | Date.Mar -> "Mars"
+	 | Date.Mar -> "March"
 	 | Date.Apr -> "April"
 	 | Date.May -> "May"
 	 | Date.Jun -> "June"
@@ -296,7 +301,7 @@ struct
       match read_word () with
       | "AM" -> pm := 0
       | "PM" -> pm := 12
-      | s -> not_match "%p" "s"
+      | s -> not_match "%p" ("\"" ^ s ^ "\"")
     in
     let parse_S () = second := read_number 2 in
     let parse_V fmt =
@@ -397,7 +402,7 @@ let cannot_create_event kind args =
   if List.exists ((=) (-1)) args then
     raise (Invalid_argument ("Cannot create the " ^ kind))
 
-module DatePrinter = 
+module Date = 
   Make(struct 
 	 include Date
 	 let make y m d _ _ _ =
@@ -409,7 +414,9 @@ module DatePrinter =
 	 let second _ = bad_format "second"
        end)
 
-module TimePrinter = 
+module DatePrinter = Date
+
+module Time = 
   Make(struct
 	 include Time
 	 let make _ _ _ h m s =
@@ -425,7 +432,35 @@ module TimePrinter =
 	 let year _ = bad_format "year"
        end)
 
-module CalendarPrinter = 
+module TimePrinter = Time
+
+module Ftime = 
+  Make(struct
+	 include Ftime
+	 let make _ _ _ h m s =
+	   cannot_create_event "time" [ h; m; s ];
+	   make h m (Second.from_int s)
+	 let second x = Second.to_int (second x)
+	 let default_format = "%T"
+	 let day_of_week _ = bad_format "day_of_week"
+	 let day_of_month _ = bad_format "day_of_month"
+	 let day_of_year _ = bad_format "day_of_year"
+	 let week _ = bad_format "week"
+	 let month _ = bad_format "month"
+	 let int_month _ = bad_format "int_month"
+	 let year _ = bad_format "year"
+       end)
+
+module Precise_Calendar = 
+  Make(struct
+	 include Calendar.Precise
+	 let make y m d h mn s =
+	   cannot_create_event "calendar" [ y; m; d; h; mn; s ];
+	   make y m d h mn s
+	 let default_format = "%i %T"
+       end)
+
+module Calendar = 
   Make(struct
 	 include Calendar
 	 let make y m d h mn s =
@@ -433,3 +468,25 @@ module CalendarPrinter =
 	   make y m d h mn s
 	 let default_format = "%i %T"
        end)
+
+module CalendarPrinter = Calendar
+
+module Precise_Fcalendar = 
+  Make(struct
+	 include Fcalendar.Precise
+	 let make y m d h mn s =
+	   cannot_create_event "calendar" [ y; m; d; h; mn; s ];
+	   make y m d h mn (Time.Second.from_int s)
+	 let second s = Time.Second.to_int (second s)
+	 let default_format = "%i %T"
+       end)
+
+module Fcalendar = 
+  Make(struct
+	 include Fcalendar
+	 let make y m d h mn s =
+	   cannot_create_event "calendar" [ y; m; d; h; mn; s ];
+	   make y m d h mn (Time.Second.from_int s)
+	 let second s = Time.Second.to_int (second s)
+	 let default_format = "%i %T"
+       end)
