@@ -1,7 +1,8 @@
-(*i $Id: test_date.ml,v 1.18 2006/07/07 13:48:10 signoles Exp $ i*)
+(*i $Id: test_date.ml,v 1.21 2008/02/08 13:06:45 signoles Exp $ i*)
 
-Printf.printf "\nTests of Date:\n\n";;
+Printf.printf "Tests of Date:\n";;
 
+open CalendarLib;;
 open Date;;
 include Gen_test;;
 reset ();;
@@ -63,6 +64,10 @@ test (nth_weekday_of_month 2004 Oct Thu 4 = make 2004 10 28)
   "nth_weekday_of_month";;
 test (nth_weekday_of_month 2006 Mar Fri 3 = make 2006 3 17) 
   "nth_weekday_of_month";;
+test (equal (from_day_of_year 2008 39) (make 2008 2 8)) 
+  "from_day_of_year";;
+test (is_valid_date 2008 2 8) "is_valid_date";;
+test (not (is_valid_date 2008 2 30)) "not is_valid_date";;
 
 (* Unix *)
 Time_Zone.change Time_Zone.UTC;;
@@ -87,7 +92,6 @@ test (from_unixtm { Unix.tm_sec = 0; tm_min = 0; tm_hour = 0; tm_mday = 14;
 test (from_unixtm (to_unixtm (make 2003 7 16)) = make 2003 7 16) 
   "from_unixtm to_unixtm = id";;
 
-
 (* to_business *)
 test (to_business (make 2003 1 1) = (2003, 1, Wed)) "to_business 1";;
 test (to_business (make 2003 12 31) = (2004, 1, Wed)) "to_business 2";;
@@ -113,5 +117,5 @@ test_exn (lazy (from_business 2005 53 Sun)) "from_business_bad 2";;
 
 let ok = nb_ok ();;
 let bug = nb_bug ();;
-Printf.printf "\ntests ok : %d; tests ko : %d\n" ok bug;;
+Printf.printf "tests ok : %d; tests ko : %d\n" ok bug;;
 flush stdout;;
